Struct muse_reactor::BudgetPoolConfig

source ·
#[non_exhaustive]
pub struct BudgetPoolConfig { pub maximum: usize, pub allocation_size: usize, pub start: usize, pub recharge_amount: usize, pub recharge_every: Duration, }
The settings for a budget pool in a Reactor.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
maximum: usize

The maximum budget this pool can contain.

If this is 0, there is no maximum budget.

allocation_size: usize

Each time a virtual machine runs out of budget, this is the amount of budget it should be allocated.

start: usize

When the pool is initialized, this is the initial budget of the pool.

recharge_amount: usize

When recharge_amount and recharge_every are non-zero, the budget is replenished by recharge_amount each time recharge_every elapses.

recharge_every: Duration

When recharge_amount and recharge_every are non-zero, the budget is replenished by recharge_amount each time recharge_every elapses.

Implementations

source

impl BudgetPoolConfig

source

pub const fn new() -> Self

Returns the default budget pool configuration.

source

pub const fn starting_with(self, start: usize) -> Self

Sets the starting budget for this pool.

source

pub const fn with_maximum(self, maximum: usize) -> Self

Sets the maximum budget for this pool.

source

pub const fn with_per_task_allocation(self, allocation_size: usize) -> Self

Sets the amount to allocate for each budget request.

source

pub const fn with_recharge( self, amount: usize, recharge_every: Duration, ) -> Self

Sets the budget to automatically replenish by amount every time recharge_every elapses.

source

pub fn recharges(&self) -> bool

Returns true if this configuration automatically recharges.