Struct muse_reactor::Builder

source ·
pub struct Builder<Work> { /* private fields */ }
A builder for a Reactor.

Implementations

source

impl Builder<NoWork>

source

pub fn new() -> Self

Returns a new builder for the default reactor settings.

source

pub fn new_vm<F, Work>(self, new_vm: F) -> Builder<Work>
where F: NewVm<Work>,

Customizes the process for which virtual machines are initialized.

For convenience, NewVm is implemented for Fn(&mut CollectionGuard<'_>, &ReactorHandle<Work>) where Work implements WorkUnit.

source

impl<Work> Builder<Work>
where Work: WorkUnit,

source

pub fn threads(self, thread_count: usize) -> Self

Sets the number of threads to execute tasks across.

source

pub fn work_queue_limit(self, limit: usize) -> Self

Sets the maximum number of work items in queue.

By default, work queues are not limited.

source

pub fn finish(self) -> ReactorHandle<Work>

Spawns a reactor with the given settings and returns a handle to it.